@@ -1,5 +1,6 @@
 from django.contrib import admin
-from models import Article, ArticleAdmin
+
+from .models import Article, ArticleAdmin
+
 
 admin.site.register(Article, ArticleAdmin)
-
